# Code of Conduct

The PHAGES2050 community has been fantastic since the project's start. A one-line summary of this CoC is simply a reflection of the community values already evident in practice:

In general, this means that everyone is expected to be **open**, **considerate**, and **respectful** of others no matter what their position is within the project.

We are faced with a very difficult task (Antimicrobial Resistance - AMR) that requires effort and work of many people from all continents from various fields of science, market and diverse background. Each of the community member is committed to stay fully focus their attention on this goal, adhering to the above principles.

## Reporting

All incidents should be reported by emailing m.tynecka@firt.pl.

For any report that involves the above admins/moderators, email p.tynecki@doktoranci.pb.edu.pl instead.

### Revisions

|Date| Change|
|------|---------------------------|
|2020-08-24 | Typos fixed |
|2020-08-04 | CoC first version release |